@@ -1,6 +1,16 @@
 use strict;
 use warnings;
 package Rubric;
+{
+  $Rubric::VERSION = '0.150';
+}
+# ABSTRACT: a notes and bookmarks manager with tagging
+
+
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
@@ -8,11 +18,7 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.149
-
-=cut
-
-our $VERSION = '0.149';
+version 0.150
 
 =head1 DESCRIPTION
 
@@ -45,52 +51,45 @@ and upgrades.
 For now, consult the C<todo.html> template for future milestones, or check
 L<http://rjbs.manxome.org/rubric/docs/todo>.
 
-=head1 AUTHOR
-
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
-
 =head1 THANKS
 
 ...to a lot of people whom I will try to name, in time.  Among these helpful
 people are Ian Langworth, Shawn Sorichetti, John Cappiello, and Dave O'Neill.
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org>. I will be notified, and
-then you'll automatically be notified of progress on your bug as I make
-changes.
-
-You can also find some useful people on the #rubric channel on Freenode IRC or
-on the mailing list: L<http://www.listbox.com/subscribe/?listname=rubric>
-
 =head1 SEE ALSO
 
-=over
+=over 4
 
-=item * L<http://del.icio.us/>
+=item *
+
+L<http://del.icio.us/>
 
 one of my original inspirations
 
-=item * L<http://pubweb.northwestern.edu/~zps869/nv.html>
+=item *
+
+L<http://notational.net/>
 
 Notational Velocity, another of my inspirations
 
-=item * L<http://unalog.com/>
+=item *
+
+L<http://unalog.com/>
 
 a social bookmarks system, written in Python
 
-=item * L<http://www.tecknik.net/scuttle/>
-
-a social bookmarks system, written in PHP
-
 =back
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2004-2006 Ricardo SIGNES.  This program is free software;  you can
-redistribute it and/or modify it under the same terms as Perl itself.
+Ricardo SIGNES <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2004 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
