@@ -1,22 +1,11 @@
 use strict;
 use warnings;
 package Rubric::User;
-our $VERSION = 0.149;
+{
+  $Rubric::User::VERSION = '0.150';
+}
+# ABSTRACT: a Rubric user
 
-=head1 NAME
-
-Rubric::User - a Rubric user
-
-=head1 VERSION
-
-version 0.149
-
-=head1 DESCRIPTION
-
-This class provides an interface to Rubric users.  It inherits from
-Rubric::DBI, which is a Class::DBI class.
-
-=cut
 
 use base qw(Rubric::DBI);
 use Digest::MD5 qw(md5_hex);
@@ -24,44 +13,14 @@ use Time::Piece;
 
 __PACKAGE__->table('users');
 
-=head1 COLUMNS
-
- username - the user's login name
- password - the hex md5sum of the user's password
- email    - the user's email address
- created  - the user's date of registration
-
- verification_code - the code sent to the user for verification
-                     NULL if verified
-
-=cut
 
 __PACKAGE__->columns(
 	All => qw(username password email created verification_code reset_code)
 );
 
-=head1 RELATIONSHIPS
-
-=head2 entries
-
-Every user has_many entries, which are Rubric::Entry objects.  They can be
-retrieved with the C<entries> accessor, as usual.
-
-=cut
 
 __PACKAGE__->has_many(entries => 'Rubric::Entry' );
 
-=head2 tags
-
-A user has as "his" tags all the tags that occur on his entries.  There exist a
-number of accessors for his tag list.
-
-=head3 tags
-
-This returns an arrayref of all the user's (non-system) tags in their database
-colation order.
-
-=cut
 
 __PACKAGE__->set_sql(tags => <<'' );
 SELECT DISTINCT tag
@@ -78,13 +37,6 @@ sub tags {
 	[ map { @$_ } @$tags ];
 }
 
-=head3 tags_counted
-
-This returns an arrayref of arrayrefs, each containing a tag name and the
-number of entries tagged with that tag.  The pairs are sorted in colation order
-by tag name.
-
-=cut
 
 __PACKAGE__->set_sql(tags_counted => <<'' );
 SELECT DISTINCT tag, COUNT(*) AS count
@@ -102,12 +54,6 @@ sub tags_counted {
 	return $tags;
 }
 
-=head3 related_tags(\@tags, \%context)
-
-This method returns a reference to an array of tags related to all the given
-tags.  Tags are related if they occur together on entries.  
-
-=cut
 
 sub related_tags {
 	my ($self, $tags, $context) = @_;
@@ -132,12 +78,6 @@ sub related_tags {
 	$self->db_Main->selectcol_arrayref($query, undef, $self->username);
 }
 
-=head3 related_tags_counted(\@tags, \%context)
-
-This is the obvious conjunction of C<related_tags> and C<tags_counted>.  It
-returns an arrayref of arrayrefs, each a pair of tag/occurance values.
-
-=cut
 
 sub related_tags_counted {
 	my ($self, $tags, $context) = @_;
@@ -166,14 +106,6 @@ sub related_tags_counted {
 	$self->db_Main->selectall_arrayref($query, undef, $self->username);
 }
 
-=head1 INFLATIONS
-
-=head2 created
-
-The created column is stored as seconds since epoch, but inflated to
-Time::Piece objects.
-
-=cut
 
 __PACKAGE__->has_a(created => 'Time::Piece', deflate => 'epoch');
 
@@ -184,26 +116,6 @@ sub _create_times {
 	$self->created(scalar gmtime) unless defined $self->{created};
 }
 
-=head1 METHODS
-
-=head2 quick_entry(\%entry)
-
-This method creates or updates an entry for the user.  The passed entry should
-include the following data:
-
- uri         - the URI for the entry
- tags        - the tags for the entry, as a space delimited string
- title       - the title for the entry
- description - the description for the entry
- body        - the body for the entry
-
-If an entry for the link exists, it is updated.  Existing tags are replaced
-with the new tags.  If no entry exists, the Rubric::Link is created if needed,
-and a new entry is then created.
-
-The Rubric::Entry object is returned.
-
-=cut
 
 sub quick_entry {
 	my ($self, $entry) = @_;
@@ -233,12 +145,6 @@ sub quick_entry {
 	return $new_entry;
 }
 
-=head2 verify($code)
-
-If the given code matches this user's C<verification_code>, the user will be
-verified; that is, his C<verification_code> will be undefined.
-
-=cut
 
 sub verify {
 	my ($self, $code) = @_;
@@ -253,14 +159,6 @@ sub verify {
 	return;
 }
 
-=head2 reset_password($code)
-
-If the given code matches this user's C<reset_code>, the user's password will be
-reset via C<randomize_password> and his reset code will be undefined.  If
-successful, the new password is returned.  Otherwise, the routine returns
-false.
-
-=cut
 
 sub reset_password {
 	my ($self, $code) = @_;
@@ -276,12 +174,6 @@ sub reset_password {
 	return;
 }
 
-=head2 randomize_password
-
-This method resets the user's password to a pseudo-random string and returns
-the new password.
-
-=cut
 
 sub __random_string {
 	my $length = 15;
@@ -301,12 +193,6 @@ sub randomize_password {
 	return $password;
 }
 
-=head2 randomize_reset_code
-
-This method resets the user's reset code to the md5sum of a pseudo-random
-string.
-
-=cut
 
 sub randomize_reset_code {
 	my ($self) = @_;
@@ -315,12 +201,6 @@ sub randomize_reset_code {
 	$self->update;
 }
 
-=head2 randomize_verification_code
-
-This method resets the user's verification code to the md5sum of a
-pseudo-random string.
-
-=cut
 
 sub randomize_verification_code {
 	my ($self) = @_;
@@ -329,24 +209,130 @@ sub randomize_verification_code {
 	$self->update;
 }
 
-=head1 TODO
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Rubric::User - a Rubric user
+
+=head1 VERSION
+
+version 0.150
+
+=head1 DESCRIPTION
+
+This class provides an interface to Rubric users.  It inherits from
+Rubric::DBI, which is a Class::DBI class.
+
+=head1 COLUMNS
+
+ username - the user's login name
+ password - the hex md5sum of the user's password
+ email    - the user's email address
+ created  - the user's date of registration
+
+ verification_code - the code sent to the user for verification
+                     NULL if verified
+
+=head1 RELATIONSHIPS
+
+=head2 entries
+
+Every user has_many entries, which are Rubric::Entry objects.  They can be
+retrieved with the C<entries> accessor, as usual.
+
+=head2 tags
+
+A user has as "his" tags all the tags that occur on his entries.  There exist a
+number of accessors for his tag list.
+
+=head3 tags
+
+This returns an arrayref of all the user's (non-system) tags in their database
+colation order.
+
+=head3 tags_counted
+
+This returns an arrayref of arrayrefs, each containing a tag name and the
+number of entries tagged with that tag.  The pairs are sorted in colation order
+by tag name.
+
+=head3 related_tags(\@tags, \%context)
+
+This method returns a reference to an array of tags related to all the given
+tags.  Tags are related if they occur together on entries.  
+
+=head3 related_tags_counted(\@tags, \%context)
+
+This is the obvious conjunction of C<related_tags> and C<tags_counted>.  It
+returns an arrayref of arrayrefs, each a pair of tag/occurance values.
+
+=head1 INFLATIONS
+
+=head2 created
+
+The created column is stored as seconds since epoch, but inflated to
+Time::Piece objects.
+
+=head1 METHODS
+
+=head2 quick_entry(\%entry)
+
+This method creates or updates an entry for the user.  The passed entry should
+include the following data:
+
+ uri         - the URI for the entry
+ tags        - the tags for the entry, as a space delimited string
+ title       - the title for the entry
+ description - the description for the entry
+ body        - the body for the entry
+
+If an entry for the link exists, it is updated.  Existing tags are replaced
+with the new tags.  If no entry exists, the Rubric::Link is created if needed,
+and a new entry is then created.
+
+The Rubric::Entry object is returned.
+
+=head2 verify($code)
+
+If the given code matches this user's C<verification_code>, the user will be
+verified; that is, his C<verification_code> will be undefined.
+
+=head2 reset_password($code)
+
+If the given code matches this user's C<reset_code>, the user's password will be
+reset via C<randomize_password> and his reset code will be undefined.  If
+successful, the new password is returned.  Otherwise, the routine returns
+false.
+
+=head2 randomize_password
+
+This method resets the user's password to a pseudo-random string and returns
+the new password.
+
+=head2 randomize_reset_code
+
+This method resets the user's reset code to the md5sum of a pseudo-random
+string.
+
+=head2 randomize_verification_code
+
+This method resets the user's verification code to the md5sum of a
+pseudo-random string.
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org>. I will be notified, and
-then you'll automatically be notified of progress on your bug as I make
-changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004 Ricardo SIGNES.  This program is free software;  you can
-redistribute it and/or modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
