@@ -1,68 +1,18 @@
 use strict;
 use warnings;
 package Rubric::WebApp;
+{
+  $Rubric::WebApp::VERSION = '0.150';
+}
+# ABSTRACT: the web interface to Rubric
 
-=head1 NAME
-
-Rubric::WebApp - the web interface to Rubric
-
-=head1 VERSION
-
-version 0.149
-
-=cut
-
-our $VERSION = '0.149';
-
-=head1 SYNOPSIS
-
- use strict;
- use warnings;
- use Rubric::WebApp;
- Rubric::WebApp->new->run();
-
-It's a CGI::Application!
-
-=head1 DESCRIPTION
-
-Rubric::WebApp provides a CGI-based interface to Rubric data.  It's built on
-top of CGI::Application, which does most of the boring work.  This module's
-code sets up the dispatch tables and implements the responses to various
-queries.
-
-=head1 REQUESTS DISPATCH
-
-Requests are I<mostly> path-based, though some involve form submission.  The
-basic dispatch table looks something like this:
-
- request      | description                               | method called
- -------------+-------------------------------------------+--------------
- /login       | log in to a user account                  | login
- /logout      | log out                                   | logout
- /preferences | view or change account settings           | preferences
- /newuser     | create a new user account                 | newuser
- /verify      | verify a pending user account             | verify
- /link        | view the details of entries for a link    | link
- /post        | post or edit an entry (must be logged in) | post
- /edit        | edit an entry (must be logged in)         | edit
- /delete      | delete an entry (must be logged in)       | delete
- /entry/ENTRY | find and display the identified entry     | entry
- /entries/Q   | find and display results for query Q      | entries
- /~USER/TAGS  | see a user's entries for given tags       | (in flux)
- /doc/PAGE    | view the named page in the documentation  | doc
- /style/PAGE  | get the named style sheet                 | style 
-
-If the system is private and no user is logged in, the default action is to
-display a login screen.  If the system is public, or a user is logged in, the
-default action is to display entries.
-
-=cut
 
+use CGI::Application 3;
 use base qw(CGI::Application);
 use CGI::Carp qw(fatalsToBrowser);
 
 use Digest::MD5 qw(md5_hex);
-use Encode qw(decode_utf8);
+use Encode 2 qw(decode_utf8);
 
 use HTML::TagCloud;
 use DateTime;
@@ -78,14 +28,6 @@ use Rubric::WebApp::Session;
 
 use String::Truncate qw(elide);
 
-=head1 METHODS
-
-=head2 redirect($uri, $message)
-
-This method simplifies redirection; it redirects to the given URI, printing the
-given message as the body of the HTTP response.
-
-=cut
 
 sub redirect {
   my ($self, $uri, $message) = @_;
@@ -95,11 +37,6 @@ sub redirect {
   return $message;
 }
 
-=head2 redirect_root($message)
-
-This is shorthand to redirect to the Rubric's root URI.  It calls C<redirect>.
-
-=cut
 
 sub redirect_root {
   my ($self, $message) = @_;
@@ -107,12 +44,6 @@ sub redirect_root {
   return $self->redirect(Rubric::Config->uri_root, $message);
 }
 
-=head2 cgiapp_init
-
-This method is called during CGI::Application's initialization.  It sets up the
-session configuration.
-
-=cut
 
 sub cgiapp_init {
   my ($self) = @_;
@@ -125,43 +56,22 @@ sub cgiapp_init {
   $login_class->check_for_login($self);
 }
 
-=head2 cgiapp_prerun
-
-This method is called before the selected runmode.  It checks for a login,
-checks for updates to result-set paging, and starts processing the request
-path. 
-
-=cut
 
 sub cgiapp_prerun {
   my ($self) = @_;
-  
+
   $self->check_pager_data;
 
   my @path = split '/', $self->query->path_info;
   $self->param(path => [ @path[ 2 .. $#path ] ]);
 }
 
-=head2 next_path_part
-
-This method shifts the next item off of the request path and returns it.
-
-=cut
 
 sub next_path_part {
   my ($self) = @_;
   shift @{$self->param('path')};
 }
 
-=head2 check_pager_data
-
-This method is called by C<cgiapp_init>, and sets up parameters used for paging
-entry listings.  The following parameters are used:
-
- per_page - how many items per page; default 25, maximum 100; stored in session;
- page     - which page to display; default 1
-
-=cut
 
 sub check_pager_data {
   my ($self) = @_;
@@ -171,7 +81,7 @@ sub check_pager_data {
     || $self->session->param('per_page')
     || Rubric::Config->default_page_size
   ));
- 
+
   $self->session->param('per_page', Rubric::Config->max_page_size)
      if $self->session->param('per_page') > Rubric::Config->max_page_size;
 
@@ -179,21 +89,6 @@ sub check_pager_data {
   $self->param('page',     int(($self->query->param('page') || 1)));
 }
 
-=head2 template($template, \%variables)
-
-This method is used to render a template with both provided and default
-variables.
-
-Templates are rendered by calling the C<process> method on the template
-renderer, which is retrieved by calling the C<renderer> method on the WebApp.
-
-The following variables are passed by default:
-
- current_user - the currently logged-in user (a Rubric::User object)
- per_page     - entries per page (see check_pager_data)
- page         - which page (see check_pager_data)
-
-=cut
 
 sub template {
   my ($self, $template, $stash) = @_;
@@ -212,12 +107,6 @@ sub template {
   return $output;
 }
 
-=head2 setup
-
-This method, called by CGI::Application's initialization process, sets up
-the dispatch table for requests, as described above.
-
-=cut
 
 sub setup {
   my ($self) = @_;
@@ -258,12 +147,6 @@ sub _entries_shortcut {
   $self->entries;
 }
 
-=head2 entries
-
-This passes off responsibility to the class named in the C<entries_query_class>
-configuration option.  This option defaults to Rubric::WebApp::Entries.
-
-=cut
 
 sub entries {
   my ($self) = @_;
@@ -275,11 +158,6 @@ sub entries {
   $entries_class->entries($self);
 }
 
-=head2 entry
-
-This displays the single requested entry.
-
-=cut
 
 sub entry {
   my ($self) = @_;
@@ -302,12 +180,6 @@ sub entry {
   });
 }
 
-=head2 get_entry
-
-This method gets the next part of the path, assumes it to be a Rubric::Entry
-id, and puts the corresponding entry in the "entry" parameter.
-
-=cut
 
 sub get_entry {
   my ($self) = @_;
@@ -316,12 +188,6 @@ sub get_entry {
   $self->param(entry => $entry);
 }
 
-=head2 link
-
-This runmode displays entries that point to a given link, identified either by
-URI or MD5 sum.
-
-=cut
 
 sub link {
   my ($self) = @_;
@@ -329,13 +195,6 @@ sub link {
   $self->display_entries;
 }
 
-=head2 get_link
-
-This method look for a C<uri> or, failing that, C<url> query parameter.  If
-found, it finds a Rubric::Link for that URI and puts it in the "link"
-parameter.
-
-=cut
 
 sub get_link {
   my ($self) = @_;
@@ -350,18 +209,15 @@ sub get_link {
   $self->param('link', $link);
 }
 
-=head2 tag_cloud
-
-=cut
 
 sub tag_cloud {
   my ($self, $options) = @_;
-    
+
   my $tags = Rubric::DBI->db_Main->selectall_arrayref(
-     "SELECT tag, count(*) 
-        FROM entrytags 
-       WHERE tag not like '@%' 
-    GROUP BY tag 
+     "SELECT tag, count(*)
+        FROM entrytags
+       WHERE tag not like '@%'
+    GROUP BY tag
     ORDER BY tag");
 
   my $cloud = HTML::TagCloud->new();
@@ -377,9 +233,6 @@ sub tag_cloud {
 
 }
 
-=head2 calendar
-
-=cut
 
 sub calendar {
   my ($self, $options) = @_;
@@ -431,11 +284,11 @@ sub calendar {
     nanosecond => 0,
     time_zone  => '-1700'
   )->epoch;
-  
+
   my $entries = Rubric::Entry->retrieve_from_sql(qq{
       WHERE id NOT IN (SELECT entry FROM entrytags WHERE tag = '\@private')
-        AND created > '$start' 
-        AND created < '$end' 
+        AND created > '$start'
+        AND created < '$end'
    ORDER BY created}
   );
 
@@ -450,7 +303,7 @@ sub calendar {
     $a->push_content($title);
     $div->push_content($a);
     $calendar->item($day)->push_content($div);
-  } 
+  }
 
   my $prev_month = $month;
   my $prev_year = $year;
@@ -470,11 +323,11 @@ sub calendar {
 
   return $self->template('calendar' => {
     calendar => $calendar,
-    prev_link => { 
+    prev_link => {
       month => sprintf("%02d", $prev_month),
       year  => $prev_year,
     },
-    next_link => { 
+    next_link => {
       month => sprintf("%02d", $next_month),
       year  => $next_year,
     },
@@ -483,12 +336,6 @@ sub calendar {
 
 }
 
-=head2 login
-
-If the user is logged in, this request is immediately redirected to the root of
-the Rubric site.  Otherwise, a login form is provided.
-
-=cut
 
 sub login {
   my ($self) = @_;
@@ -512,12 +359,6 @@ sub login {
   });
 }
 
-=head2 logout
-
-This run mode unsets the "current_user" parameter in the session and the WebApp
-object, then redirects the user to the root of the Rubric site.
-
-=cut
 
 sub logout {
   my ($self) = @_;
@@ -527,12 +368,6 @@ sub logout {
   return $self->redirect_root("Logged out...");
 }
 
-=head2 reset_password
-
-This run mode allows a user to request that his password be reset and emailled
-to him.
-
-=cut
 
 sub reset_password {
   my ($self) = @_;
@@ -553,11 +388,6 @@ sub reset_password {
 
 }
 
-=head2 setup_reset_code
-
-This routine gets a reset code for the user and emails it to him.
-
-=cut
 
 sub setup_reset_code {
   my ($self, $user) = @_;
@@ -568,18 +398,12 @@ sub setup_reset_code {
   $self->template("reset_sent");
 }
 
-=head2 preferences
-
-This method displays account information for the current user.  Some account
-settings may be changed.
-
-=cut
 
 sub preferences {
   my ($self) = @_;
 
-  return $self->login unless $self->param('current_user');  
-  
+  return $self->login unless $self->param('current_user');
+
   return $self->template("preferences")
     unless my %prefs = $self->_get_prefs_form;
 
@@ -590,12 +414,6 @@ sub preferences {
   $self->update_user(\%prefs);
 }
 
-=head2 update_user(\%prefs)
-
-This method will update the current user object with the changes in C<%prefs>,
-which is passed by the C<preferences> method.
-
-=cut
 
 sub update_user {
   my ($self, $prefs) = @_;
@@ -617,40 +435,7 @@ sub _get_prefs_form {
   return %form;
 }
 
-=head2 validate_prefs(\%prefs)
 
-Given a set of preference updates from a form submission, this method validates
-them and returns a description of the validation results.  This method will
-probably be redesigned (possibly with Data::FormValidator) in the future.
-Don't count on its interface.
-
-=cut
-
-=begin future
-
-sub validate_prefs {
-  my ($self, $prefs) = @_;
-  require Data::FormValidator;
-
-  my $profile = {
-    required     => [qw(password)],
-    optional     => [qw(password_1 password_2 email)],
-    constraints  => {
-      email => 'email',
-      password_1 => {
-        params     => [qw(password_1 password_2)],
-        constraint => sub { $_[0] eq $_[1] },
-      }
-    },
-    dependency_groups => { new_password => [qw(password_1 password_2)] }
-  };
-  
-  my $results = Data::FormValidator->check($prefs, $profile);
-}
-
-=end future
-
-=cut
 
 sub validate_prefs {
   my ($self, $prefs) = @_;
@@ -683,15 +468,6 @@ sub validate_prefs {
   return %errors;
 }
 
-=head2 newuser
-
-If the proper form information is present, this runmode creates a new user
-account.  If not, it presents a form.
-
-If a user is already logged in, the user is redirected to the root of the
-Rubric.
-
-=cut
 
 sub newuser {
   my ($self) = @_;
@@ -701,7 +477,7 @@ sub newuser {
 
   return $self->redirect_root("Already logged in...")
     if $self->param('current_user');
-  
+
   my %newuser;
   $newuser{$_} = $self->query->param($_)
     for qw(username password_1 password_2 email);
@@ -714,14 +490,6 @@ sub newuser {
   }
 }
 
-=head2 validate_newuser_form(\%newuser)
-
-Given a set of user data from a form submission, this method validates them and
-returns a description of the validation results.  This method will probably be
-redesigned (possibly with Data::FormValidator) in the future.  Don't count on
-its interface.
-
-=cut
 
 sub validate_newuser_form {
   my ($self, $newuser) = @_;
@@ -734,7 +502,7 @@ sub validate_newuser_form {
     undef $newuser->{username};
     $errors{username_taken} = 1;
   }
-  
+
   unless ($newuser->{email}) {
     $errors{email_missing} = 1;
   } elsif ($newuser->{email} and $newuser->{email} !~ $Email::Address::addr_spec) {
@@ -753,12 +521,6 @@ sub validate_newuser_form {
   return %errors;
 }
 
-=head2 create_newuser(\%newuser)
-
-This method creates a new user account from the given description.  It sends
-the user a validation email (if needed) and displays an account creation page.
-
-=cut
 
 sub create_newuser {
   my ($self, %newuser) = @_;
@@ -779,11 +541,6 @@ sub create_newuser {
   $self->template("account_created");
 }
 
-=head2 send_reset_email_to($user)
-
-This method sends an email to the given user with a URI to reset his password.
-
-=cut
 
 sub send_reset_email_to {
   my ($self, $user) = @_;
@@ -797,11 +554,6 @@ sub send_reset_email_to {
   send SMTP => $message => Rubric::Config->smtp_server;
 }
 
-=head2 send_verification_email_to($user)
-
-This method sends a verification email to the given user.
-
-=cut
 
 sub send_verification_email_to {
   my ($self, $user) = @_;
@@ -815,12 +567,6 @@ sub send_verification_email_to {
   send SMTP => $message => Rubric::Config->smtp_server;
 }
 
-=head2 verify
-
-This runmode attempts to verify a user account.  It expects a request to be
-in the form: C< /verify/username/verification_code >
-
-=cut
 
 sub verify {
   my ($self) = @_;
@@ -838,12 +584,6 @@ sub verify {
                               : $self->redirect_root("BAD USER NO VALIDATION");
 }
 
-=head2 get_reset_code
-
-This gets the next part of the path and puts it in the C<reset_code>
-parameter.
-
-=cut
 
 sub get_reset_code {
   my ($self) = @_;
@@ -851,12 +591,6 @@ sub get_reset_code {
   $self->param(reset_code => $self->next_path_part);
 }
 
-=head2 get_verification_code
-
-This gets the next part of the path and puts it in the C<verification_code>
-parameter.
-
-=cut
 
 sub get_verification_code {
   my ($self) = @_;
@@ -864,11 +598,6 @@ sub get_verification_code {
   $self->param(verification_code => $self->next_path_part);
 }
 
-=head2 get_user
-
-This gets the next part of the path and puts it in the C<user> parameter.
-
-=cut
 
 sub get_user {
   my ($self) = @_;
@@ -876,13 +605,6 @@ sub get_user {
   $self->param(user => Rubric::User->retrieve($self->next_path_part) || '');
 }
 
-=head2 display_entries
-
-This method searches (with Rubric::Entry) for entries matching the requested
-user and tags.  It pages the result (with C<page_entries>) and renders the
-resulting page with C<render_entries>.
-
-=cut
 
 sub display_entries {
   my ($self) = @_;
@@ -906,17 +628,6 @@ sub display_entries {
   $self->page_entries($entries)->render_entries;
 }
 
-=head2 page_entries($iterator)
-
-Given a Class::DBI::Iterator, this method sets up parameters describing the
-current page.  Most importantly, it retrieves an Iterator for the slice of
-entries representing the current page.  The following parameters are set:
-
- entries - a Class::DBI::Iterator for the current page's entries
- count   - the number of entries in the entire set
- pages   - the number of pages the set spans
-
-=cut
 
 sub page_entries {
   my ($self, $iterator) = @_;
@@ -934,12 +645,6 @@ sub page_entries {
   return $self;
 }
 
-=head2 render_entries
-
-This method renders a template to display the set of entries set up by
-C<page_entries>.
-
-=cut
 
 sub render_entries {
   my ($self, $options) = @_;
@@ -960,19 +665,13 @@ sub render_entries {
   });
 }
 
-=head2 edit
-
-If the user isn't logged in, it redirects to demand a login.  If he is, it
-displays a post form, completed with the given entry's data.
-
-=cut
 
 sub edit {
   my ($self) = @_;
 
   return $self->template('no_entry', { reason => 'missing' })
     unless $self->get_entry;
-  
+
   return $self->template('no_entry', { reason => 'access' })
     unless $self->param('entry')->user eq $self->param('current_user');
 
@@ -981,18 +680,6 @@ sub edit {
   return $self->post_form();
 }
 
-=head2 post
-
-This method wants to be simplified.
-
-If the user isn't logged in, it redirects to demand a login.  If he is, it
-checks whether it can create a new entry.  If so, it tries to.  If not, it
-displays a form for doing so.  If the user already has an entry for the given
-URI, the existing entry is passed to the form renderer.
-
-If a new entry is created, the user is redirected to his entry listing.
-
-=cut
 
 sub _post_form_contents {
   my ($self) = @_;
@@ -1002,13 +689,11 @@ sub _post_form_contents {
     for qw(entryid uri title description tags body);
 
   for (qw(uri title description body tags)) {
-    my $decoded;
     my $ok = eval {
-      $decoded = decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
+      decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
       1;
     };
-    $error{$_} = "Invalid characters in $_." unless $ok;
-    $form{$_} = $decoded if $ok;
+    $error{$_} = "Invalid UTF-8 characters in $_." unless $ok;
   }
 
   eval { $form{uri} = URI->new($form{uri})->canonical; };
@@ -1027,7 +712,7 @@ sub _post_form_contents {
   eval { Rubric::Entry->tags_from_string($form{tags}) };
   $error{tags} = "Tags may only contain letters, numbers, dot, colon, and asterisk." if $@;
 
-  $error{title} = "You must supply a title." if 
+  $error{title} = "You must supply a title." if
     $self->query->param('submit') and not length $form{title};
 
   if ($form{uri} and Rubric::Config->one_entry_per_link) {
@@ -1041,14 +726,14 @@ sub _post_form_contents {
       }
     }
   }
-  
+
   return (\%form, \%error);
 }
 
 sub post {
   my ($self) = @_;
 
-  return $self->login unless my $user = $self->param('current_user');  
+  return $self->login unless my $user = $self->param('current_user');
 
   my ($form, $error) = $self->_post_form_contents;
 
@@ -1056,7 +741,7 @@ sub post {
     if not $self->query->param('submit')
         or %$error
         or not my $entry = $self->param('current_user')->quick_entry($form);
-  
+
   my $when_done = $self->query->param('when_done');
   my $goto;
 
@@ -1070,11 +755,6 @@ sub post {
   $self->redirect( $goto, "Posted..." );
 }
 
-=head2 post_form
-
-This method renders a form for the user to create a new entry.
-
-=cut
 
 sub post_form {
   my ($self, $form, $error) = @_;
@@ -1090,21 +770,11 @@ sub post_form {
   });
 }
 
-=head2 delete
-
-This method wants to be simplified.  It's largely copied from C<post>.
-
-If the user isn't logged in, it redirects to demand a login.  If he is, it
-checks whether the user has an entry for the given URI.  If so, it's deleted.
-
-Either way, the user is redirected to his entry listing.
-
-=cut
 
 sub delete {
   my ($self) = @_;
 
-  return $self->login unless my $user = $self->param('current_user');  
+  return $self->login unless my $user = $self->param('current_user');
 
   return $self->redirect_root("No such entry...")
     unless $self->get_entry;
@@ -1115,16 +785,11 @@ sub delete {
   $self->param('entry')->delete;
 
   my $goto = $self->query->param('then_goto')
-           || Rubric::WebApp::URI->entries({ username => $user }); 
+           || Rubric::WebApp::URI->entries({ username => $user });
 
   return $self->redirect( $goto, "Deleted..." );
 }
 
-=head2 doc
-
-This runmode returns a mostly-static document from the template path.
-
-=cut
 
 sub doc {
   my ($self) = @_;
@@ -1136,11 +801,6 @@ sub doc {
   return $output ? $output : $self->redirect_root("no such document");
 }
 
-=head2 get_doc
-
-This gets the next part of the path and puts it in the C<doc_page> parameter.
-
-=cut
 
 sub get_doc {
   my ($self) = @_;
@@ -1150,11 +810,6 @@ sub get_doc {
                                     : ();
 }
 
-=head2 style
-
-This runmode sends the named stylesheet from the CSS path.
-
-=cut
 
 sub style {
   my ($self) = @_;
@@ -1176,30 +831,322 @@ sub style {
   return $output;
 }
 
-=head1 TODO
+1;
 
-=over 4
+__END__
+=pod
 
-=item * change email, password
+=head1 NAME
 
-=back
+Rubric::WebApp - the web interface to Rubric
+
+=head1 VERSION
+
+version 0.150
+
+=head1 SYNOPSIS
+
+ use strict;
+ use warnings;
+ use Rubric::WebApp;
+ Rubric::WebApp->new->run();
+
+It's a CGI::Application!
+
+=head1 DESCRIPTION
+
+Rubric::WebApp provides a CGI-based interface to Rubric data.  It's built on
+top of CGI::Application, which does most of the boring work.  This module's
+code sets up the dispatch tables and implements the responses to various
+queries.
+
+=head1 REQUESTS DISPATCH
+
+Requests are I<mostly> path-based, though some involve form submission.  The
+basic dispatch table looks something like this:
+
+ request      | description                               | method called
+ -------------+-------------------------------------------+--------------
+ /login       | log in to a user account                  | login
+ /logout      | log out                                   | logout
+ /preferences | view or change account settings           | preferences
+ /newuser     | create a new user account                 | newuser
+ /verify      | verify a pending user account             | verify
+ /link        | view the details of entries for a link    | link
+ /post        | post or edit an entry (must be logged in) | post
+ /edit        | edit an entry (must be logged in)         | edit
+ /delete      | delete an entry (must be logged in)       | delete
+ /entry/ENTRY | find and display the identified entry     | entry
+ /entries/Q   | find and display results for query Q      | entries
+ /~USER/TAGS  | see a user's entries for given tags       | (in flux)
+ /doc/PAGE    | view the named page in the documentation  | doc
+ /style/PAGE  | get the named style sheet                 | style
+
+If the system is private and no user is logged in, the default action is to
+display a login screen.  If the system is public, or a user is logged in, the
+default action is to display entries.
+
+=head1 METHODS
+
+=head2 redirect($uri, $message)
+
+This method simplifies redirection; it redirects to the given URI, printing the
+given message as the body of the HTTP response.
+
+=head2 redirect_root($message)
+
+This is shorthand to redirect to the Rubric's root URI.  It calls C<redirect>.
+
+=head2 cgiapp_init
+
+This method is called during CGI::Application's initialization.  It sets up the
+session configuration.
+
+=head2 cgiapp_prerun
+
+This method is called before the selected runmode.  It checks for a login,
+checks for updates to result-set paging, and starts processing the request
+path.
+
+=head2 next_path_part
+
+This method shifts the next item off of the request path and returns it.
+
+=head2 check_pager_data
+
+This method is called by C<cgiapp_init>, and sets up parameters used for paging
+entry listings.  The following parameters are used:
+
+ per_page - how many items per page; default 25, maximum 100; stored in session;
+ page     - which page to display; default 1
+
+=head2 template($template, \%variables)
+
+This method is used to render a template with both provided and default
+variables.
+
+Templates are rendered by calling the C<process> method on the template
+renderer, which is retrieved by calling the C<renderer> method on the WebApp.
+
+The following variables are passed by default:
+
+ current_user - the currently logged-in user (a Rubric::User object)
+ per_page     - entries per page (see check_pager_data)
+ page         - which page (see check_pager_data)
+
+=head2 setup
+
+This method, called by CGI::Application's initialization process, sets up
+the dispatch table for requests, as described above.
+
+=head2 entries
+
+This passes off responsibility to the class named in the C<entries_query_class>
+configuration option.  This option defaults to Rubric::WebApp::Entries.
+
+=head2 entry
+
+This displays the single requested entry.
+
+=head2 get_entry
+
+This method gets the next part of the path, assumes it to be a Rubric::Entry
+id, and puts the corresponding entry in the "entry" parameter.
+
+=head2 link
+
+This runmode displays entries that point to a given link, identified either by
+URI or MD5 sum.
+
+=head2 get_link
+
+This method look for a C<uri> or, failing that, C<url> query parameter.  If
+found, it finds a Rubric::Link for that URI and puts it in the "link"
+parameter.
+
+=head2 tag_cloud
+
+=head2 calendar
+
+=head2 login
+
+If the user is logged in, this request is immediately redirected to the root of
+the Rubric site.  Otherwise, a login form is provided.
+
+=head2 logout
+
+This run mode unsets the "current_user" parameter in the session and the WebApp
+object, then redirects the user to the root of the Rubric site.
+
+=head2 reset_password
+
+This run mode allows a user to request that his password be reset and emailled
+to him.
+
+=head2 setup_reset_code
+
+This routine gets a reset code for the user and emails it to him.
+
+=head2 preferences
+
+This method displays account information for the current user.  Some account
+settings may be changed.
+
+=head2 update_user(\%prefs)
+
+This method will update the current user object with the changes in C<%prefs>,
+which is passed by the C<preferences> method.
+
+=head2 validate_prefs(\%prefs)
+
+Given a set of preference updates from a form submission, this method validates
+them and returns a description of the validation results.  This method will
+probably be redesigned (possibly with Data::FormValidator) in the future.
+Don't count on its interface.
+
+=begin future
+
+sub validate_prefs {
+  my ($self, $prefs) = @_;
+  require Data::FormValidator;
+
+  my $profile = {
+    required     => [qw(password)],
+    optional     => [qw(password_1 password_2 email)],
+    constraints  => {
+      email => 'email',
+      password_1 => {
+        params     => [qw(password_1 password_2)],
+        constraint => sub { $_[0] eq $_[1] },
+      }
+    },
+    dependency_groups => { new_password => [qw(password_1 password_2)] }
+  };
+
+  my $results = Data::FormValidator->check($prefs, $profile);
+}
+
+=end future
+
+=head2 newuser
+
+If the proper form information is present, this runmode creates a new user
+account.  If not, it presents a form.
+
+If a user is already logged in, the user is redirected to the root of the
+Rubric.
+
+=head2 validate_newuser_form(\%newuser)
+
+Given a set of user data from a form submission, this method validates them and
+returns a description of the validation results.  This method will probably be
+redesigned (possibly with Data::FormValidator) in the future.  Don't count on
+its interface.
+
+=head2 create_newuser(\%newuser)
+
+This method creates a new user account from the given description.  It sends
+the user a validation email (if needed) and displays an account creation page.
+
+=head2 send_reset_email_to($user)
+
+This method sends an email to the given user with a URI to reset his password.
+
+=head2 send_verification_email_to($user)
+
+This method sends a verification email to the given user.
+
+=head2 verify
+
+This runmode attempts to verify a user account.  It expects a request to be
+in the form: C< /verify/username/verification_code >
+
+=head2 get_reset_code
+
+This gets the next part of the path and puts it in the C<reset_code>
+parameter.
+
+=head2 get_verification_code
+
+This gets the next part of the path and puts it in the C<verification_code>
+parameter.
+
+=head2 get_user
+
+This gets the next part of the path and puts it in the C<user> parameter.
+
+=head2 display_entries
+
+This method searches (with Rubric::Entry) for entries matching the requested
+user and tags.  It pages the result (with C<page_entries>) and renders the
+resulting page with C<render_entries>.
+
+=head2 page_entries($iterator)
+
+Given a Class::DBI::Iterator, this method sets up parameters describing the
+current page.  Most importantly, it retrieves an Iterator for the slice of
+entries representing the current page.  The following parameters are set:
+
+ entries - a Class::DBI::Iterator for the current page's entries
+ count   - the number of entries in the entire set
+ pages   - the number of pages the set spans
+
+=head2 render_entries
+
+This method renders a template to display the set of entries set up by
+C<page_entries>.
+
+=head2 edit
+
+If the user isn't logged in, it redirects to demand a login.  If he is, it
+displays a post form, completed with the given entry's data.
+
+=head2 post
+
+This method wants to be simplified.
+
+If the user isn't logged in, it redirects to demand a login.  If he is, it
+checks whether it can create a new entry.  If so, it tries to.  If not, it
+displays a form for doing so.  If the user already has an entry for the given
+URI, the existing entry is passed to the form renderer.
+
+If a new entry is created, the user is redirected to his entry listing.
+
+=head2 post_form
+
+This method renders a form for the user to create a new entry.
+
+=head2 delete
+
+This method wants to be simplified.  It's largely copied from C<post>.
+
+If the user isn't logged in, it redirects to demand a login.  If he is, it
+checks whether the user has an entry for the given URI.  If so, it's deleted.
+
+Either way, the user is redirected to his entry listing.
+
+=head2 doc
+
+This runmode returns a mostly-static document from the template path.
+
+=head2 get_doc
+
+This gets the next part of the path and puts it in the C<doc_page> parameter.
+
+=head2 style
+
+This runmode sends the named stylesheet from the CSS path.
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org>. I will be notified, and
-then you'll automatically be notified of progress on your bug as I make
-changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004 Ricardo SIGNES.  This program is free software;  you can
-redistribute it and/or modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
