@@ -1,39 +1,18 @@
 use strict;
 use warnings;
 package Rubric::WebApp::URI;
-our $VERSION = '0.149';
+{
+  $Rubric::WebApp::URI::VERSION = '0.150';
+}
+# ABSTRACT: URIs for Rubric web requests
 
-=head1 NAME
-
-Rubric::WebApp::URI - URIs for Rubric web requests
-
-=head1 VERSION
-
-version 0.149
-
-=head1 DESCRIPTION
-
-This module provides methods for generating the URIs for Rubric requests.
-
-=cut
 
 use Rubric::Config;
+use Scalar::Util ();
 
-=head1 METHODS
-
-=head2 root
-
-the URI for the root of the Rubric; taken from uri_root in config
-
-=cut
 
 sub root { Rubric::Config->uri_root }
-	
-=head2 stylesheet
 
-the URI for the stylesheet
-
-=cut
 
 sub stylesheet {
   my $href = Rubric::Config->css_href;
@@ -41,27 +20,12 @@ sub stylesheet {
   return Rubric::Config->uri_root . '/style/rubric.css';
 }
 
-=head2 logout
-
-URI to log out
-
-=cut
 
 sub logout { Rubric::Config->uri_root . '/logout' }
 
-=head2 login
-
-URI to form for log in
-
-=cut
 
 sub login { Rubric::Config->uri_root . '/login' }
 
-=head2 reset_password
-
-URI to reset user password
-
-=cut
 
 sub reset_password {
 	my ($class, $arg) = @_;
@@ -72,26 +36,12 @@ sub reset_password {
 	return $uri;
 }
 
-=head2 newuser
-
-URI to form for new user registration form;  returns false if registration is
-closed.
-
-=cut
 
 sub newuser {
 	return if Rubric::Config->registration_closed;
 	return Rubric::Config->uri_root . '/newuser';
 }
 
-=head2 entries(\%arg)
-
-URI for entry listing; valid keys for C<%arg>:
-
- user - entries for one user
- tags - arrayref of tag names
-
-=cut
 
 sub entries {
 	my ($class, $arg) = @_;
@@ -113,59 +63,34 @@ sub entries {
 	return $uri;
 }
 
-=head2 entry($entry)
-
-URI to view entry
-
-=cut
 
 sub entry {
 	my ($class, $entry) = @_;
-	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
+	return unless Scalar::Util::blessed($entry) && $entry->isa('Rubric::Entry');
 
 	return Rubric::Config->uri_root . "/entry/" . $entry->id;
 }
 
 
-=head2 edit_entry($entry)
-
-URI to edit entry
-
-=cut
 
 sub edit_entry {
 	my ($class, $entry) = @_;
-	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
+	return unless Scalar::Util::blessed($entry) && $entry->isa('Rubric::Entry');
 
 	return Rubric::Config->uri_root . "/edit/" . $entry->id;
 }
 
-=head2 delete_entry($entry)
-
-URI to delete entry
-
-=cut
 
 sub delete_entry {
 	my ($class, $entry) = @_;
-	return unless UNIVERSAL::isa($entry,  'Rubric::Entry');
+	return unless Scalar::Util::blessed($entry) && $entry->isa('Rubric::Entry');
 
 	return Rubric::Config->uri_root . "/delete/" . $entry->id;
 }
 
-=head2 post_entry
-
-URI for new entry form
-
-=cut
 
 sub post_entry { Rubric::Config->uri_root . "/post"; }
 
-=head2 by_date
-
-URI for by_date
-
-=cut
 
 sub by_date {
 	my ($class) = @_;
@@ -181,66 +106,125 @@ sub by_date {
 
 
 
-=head2 tag_cloud
 
-URI for all tags / tag cloud
-
-=cut
-
-sub tag_cloud { 
+sub tag_cloud {
 	my ($class) = @_;
 	Rubric::Config->uri_root . "/tag_cloud";
 }
 
-=head2 preferences
-
-URI for preferences form
-
-=cut
 
 
 sub preferences { Rubric::Config->uri_root . "/preferences"; }
 
-=head2 verify_user
-
-URI for new entry form
-
-=cut
 
 sub verify_user {
 	my ($class, $user) = @_;
 	Rubric::Config->uri_root . "/verify/$user/" . $user->verification_code;
 }
 
-=head2 doc($doc_page)
-
-URI for documentation page.
-
-=cut
 
 sub doc {
 	my ($class, $doc_page) = @_;
 	Rubric::Config->uri_root . "/doc/" . $doc_page;
 }
 
-=head1 TODO
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Rubric::WebApp::URI - URIs for Rubric web requests
+
+=head1 VERSION
+
+version 0.150
+
+=head1 DESCRIPTION
+
+This module provides methods for generating the URIs for Rubric requests.
+
+=head1 METHODS
+
+=head2 root
+
+the URI for the root of the Rubric; taken from uri_root in config
+
+=head2 stylesheet
+
+the URI for the stylesheet
+
+=head2 logout
+
+URI to log out
+
+=head2 login
+
+URI to form for log in
+
+=head2 reset_password
+
+URI to reset user password
+
+=head2 newuser
+
+URI to form for new user registration form;  returns false if registration is
+closed.
+
+=head2 entries(\%arg)
+
+URI for entry listing; valid keys for C<%arg>:
+
+ user - entries for one user
+ tags - arrayref of tag names
+
+=head2 entry($entry)
+
+URI to view entry
+
+=head2 edit_entry($entry)
+
+URI to edit entry
+
+=head2 delete_entry($entry)
+
+URI to delete entry
+
+=head2 post_entry
+
+URI for new entry form
+
+=head2 by_date
+
+URI for by_date
+
+=head2 tag_cloud
+
+URI for all tags / tag cloud
+
+=head2 preferences
+
+URI for preferences form
+
+=head2 verify_user
+
+URI for new entry form
+
+=head2 doc($doc_page)
+
+URI for documentation page.
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
-through the web interface at L<http://rt.cpan.org>. I will be notified, and
-then you'll automatically be notified of progress on your bug as I make
-changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004 Ricardo SIGNES.  This program is free software;  you can
-redistribute it and/or modify it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
